#include "menu.h"
#include "gui.h"
#include "fontutil.h"

SceneManager* menuManager = SceneManager::GetInstance();  

// GUI button; 
GUI button[3];

// 텍스처 로드하기 
// NOTE: Textures MUST be loaded after Window initialization (OpenGL context is required)
Texture2D birdImage;        // Texture loading;  


std::vector<std::string> texts
{
    "한글로 인사드립니다. 플래피버드입니다! ", 
    "게임 시작",   // 버튼1
    "점수판",   // 버튼 2
    "게임끝"  // 버튼3 
};

Font font;

void Menu::Init(int width, int height, std::string title)
{

    // 창의 사이즈 및 이름을 설정하기 
    SetWindowSize(width, height);
    SetWindowTitle(title.c_str());

   birdImage = LoadTexture("Assets/birddrawing.png");        // Texture loading

    // font = GetFont(texts);
    font = GetFont(texts, "Assets/SDKukdetopokki-bBd.otf");

    // 각 버튼 선언하기 
   button[0].Init(GetScreenWidth() - 200, GetScreenHeight() - 200, 180, 40, texts[1].c_str(), font);   // 게임 시작 버튼
   button[1].Init(GetScreenWidth() - 200, GetScreenHeight() - 140, 180, 40, texts[2].c_str(), font);  // 점수판 버튼
   button[2].Init(GetScreenWidth() - 200, GetScreenHeight() - 80, 180, 40, texts[3].c_str(), font);   // 게임 종료 버튼
}

void Menu::Tick()   // 기본적인 루프
{
    BeginDrawing();    // 레이라이브 기본 함수이다. 
    Update();
    Draw();
    EndDrawing();  // 레이라이브 기본 함수이다. 
}

Menu::Menu()
{
}

Menu::~Menu()
{
    UnloadTexture(birdImage);       // Texture unloading
    UnloadFont(font);
}

void Menu::Update()
{
    for (int i = 0; i < 3; i++)
    {
        button[i].Update();
    }

    // 버튼 선택하고 마우스 입력한 신호 받기 
    if (IsMouseButtonPressed(MOUSE_BUTTON_LEFT) && button[0].GetChecked()) menuManager->scene = Scene::game; 

    if (IsMouseButtonPressed(MOUSE_BUTTON_LEFT) && button[1].GetChecked())  menuManager->scene = Scene::scoreScene; 

    if (IsMouseButtonPressed(MOUSE_BUTTON_LEFT) && button[2].GetChecked())  menuManager->gameExit = true;
    
}

void Menu::Draw()
{
    ClearBackground(BLACK);
    DrawText("Flappy Bird Menu!", GetScreenWidth() / 2 - 160, GetScreenHeight() / 2  - 40, 40, DARKBROWN); 

   // DrawTexture(birdImage, GetScreenWidth() / 2, 80, WHITE);   // 텍스쳐 그리기. 여기에서는 새 그림 

   // 버튼 그리기 
   for (int i = 0; i < 3;i++)
   {
        button[i].Draw();
   }

    // Draw provided text with loaded font, containing all required codepoint glyphs
    DrawTextEx(font, texts[0].c_str(), (Vector2) { 100, 110 }, 32, 5, WHITE);
    DrawTextEx(font, texts[1].c_str(), (Vector2) { 100, 160 }, 32, 5, WHITE);
    DrawTextEx(font, texts[2].c_str(), (Vector2) { 100, 210 }, 32, 5, WHITE);
}

